{ **************************************************************************** }
{ **    Addin Development Kit                                               ** }
{ **    (c) 2000 by Dott. Cosimo De Michele                                 ** }
{ **                                                                        ** }
{ **    Wizard per creare in maniera automatica un nuovo Addin,             ** }
{ **    facilmente integrabile nell'architettura gi esistente.             ** }
{ **************************************************************************** }

unit AddinWizard;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, ExptIntf, ToolIntf, IStreams, EditIntf, dsgnintf;

type

  TAddinWizard = class( TIExpert )
  public
    function GetIDString: string; Override;
    function GetStyle: TExpertStyle; Override;
    function GetState: TExpertState; Override;
    function GetMenuText: string; Override;
    function GetPage: string; Override;
    function GetName: string; Override;
    function GetAuthor: string; Override;
    function GetComment: string; Override;
    function GetGlyph: HICON; Override;
    procedure Execute; Override;
  end;


  {$IFDEF VER100}
  TAddinProjectCreator = class(TIProjectCreator)
  {$ELSE}
  TAddinProjectCreator = class(TIProjectCreatorEx)
  {$ENDIF}
  public
    constructor Create;
    function Existing: Boolean; override;
    function GetFileName: string; override;
    function GetFileSystem: string; override;
    {$IFNDEF VER100}
    function GetOptionName: string; override;
    function NewOptionSource(const ProjectName: string): string; override;
    {$ENDIF}
    function NewProjectSource(const ProjectName: string): string; override;
    procedure NewDefaultModule; override;
    procedure NewProjectResource(Module: TIModuleInterface); override;
  end;


  {$IFDEF VER100}
  TAddinModuleCreator = class(TIModuleCreator)
  {$ELSE}
  TAddinModuleCreator = class(TIModuleCreatorEx)
  {$ENDIF}
  public
    constructor Create;
    function Existing: Boolean; override;
    function GetAncestorName: string; override;
    function GetFileName: string; override;
    function GetFileSystem: string; override;
    function GetFormName: string; override;
    {$IFNDEF VER100}
    function GetIntfName: string; override;
    function NewIntfSource( const UnitIdent, Form, Ancestor: string ): string; override;
    function NewModuleSource( const UnitIdent, Form, Ancestor: string ): string; override;
    {$ELSE}
    function NewModuleSource(UnitIdent, FormIdent, AncestorIdent: string ): string; override;
    {$ENDIF}
    procedure FormCreated( Form: TIFormInterface ); override;
  end;

  procedure Register;

implementation

{$R ADDINWIZ.RES}

uses
  ADKMng;

const
  CRLF = #10#13;

function TAddinWizard.GetIDString: String;
begin
   Result := 'SUD Multimedia.Addin Development Kit Wizard';
end;

function TAddinWizard.GetStyle: TExpertStyle;
begin
   Result := esProject;
end;

function TAddinWizard.GetState: TExpertState;
begin
   Result := [esEnabled];
end;

function TAddinWizard.GetMenuText: String;
begin
   Result := 'Addin Wizard';
end;

function TAddinWizard.GetName: String;
begin
   Result := 'Addin Wizard';
end;


function TAddinWizard.GetPage: string;
begin
  Result := 'Addins';
end;

function TAddinWizard.GetAuthor: string;
begin
  Result := 'Dott. Cosimo De Michele';
end;


function TAddinWizard.GetComment: String;
begin
  Result := 'Addin Development Kit architecture';
end;

function TAddinWizard.GetGlyph: HICON;
begin
  Result := LoadIcon(hInstance, 'ADDINWIZ');
end;
{
procedure TAddinWizard.Execute;
var
   ProjectCreator: TAddinProjectCreator;
begin
   if Assigned(ToolServices) then
   begin
      ProjectCreator := TAddinProjectCreator.Create();
      ToolServices.ProjectCreate(ProjectCreator, [cpLibrary]);
   end;
end;
}
procedure TAddinWizard.Execute;
var
   ModuleCreator: TAddinModuleCreator;
begin
   if Assigned(ToolServices) then
   begin
      ModuleCreator := TAddinModuleCreator.Create;
      ToolServices.ModuleCreate(ModuleCreator, [cmAddToProject, cmMainForm, cmMarkModified, cmShowForm, cmUnNamed] );
   end;
end;

{----------------------------------------------------------------------------}

constructor TAddinProjectCreator.Create;
begin
  inherited Create;
end;

function TAddinProjectCreator.Existing: Boolean;
begin
  Result := false;
end;

function TAddinProjectCreator.GetFileName: string;
begin
  Result := '';
end;

function TAddinProjectCreator.GetFileSystem: string;
begin
  Result := '';
end;

{$IFNDEF VER100}
function TAddinProjectCreator.GetOptionName: string;
begin
  Result := '';
end;

function TAddinProjectCreator.NewOptionSource(const ProjectName: string): string;
begin
   result := '';
end;
{$ENDIF}

function TAddinProjectCreator.NewProjectSource(const ProjectName: string): string;
begin
  result :=
  'package  '+ ProjectName + ';' + CRLF + CRLF +
  '{$R *.RES}' + CRLF +
  '{$ALIGN ON}' + CRLF +
  '{$ASSERTIONS ON}' + CRLF +
  '{$BOOLEVAL OFF}' + CRLF +
  '{$DEBUGINFO ON}' + CRLF +
  '{$EXTENDEDSYNTAX ON}' + CRLF +
  '{$IMPORTEDDATA ON}' + CRLF +
  '{$IOCHECKS ON}' + CRLF +
  '{$LOCALSYMBOLS ON}' + CRLF +
  '{$LONGSTRINGS ON}' + CRLF +
  '{$OPENSTRINGS ON}' + CRLF +
  '{$OPTIMIZATION ON}' + CRLF +
  '{$OVERFLOWCHECKS OFF}' + CRLF +
  '{$RANGECHECKS OFF}' + CRLF +
  '{$REFERENCEINFO ON}' + CRLF +
  '{$SAFEDIVIDE OFF}' + CRLF +
  '{$STACKFRAMES OFF}' + CRLF +
  '{$TYPEDADDRESS OFF}' + CRLF +
  '{$VARSTRINGCHECKS ON}' + CRLF +
  '{$WRITEABLECONST ON}' + CRLF +
  '{$MINENUMSIZE 1}' + CRLF +
  '{$IMAGEBASE $400000}' + CRLF +
  '{$DESCRIPTION ''Addin package description''}' + CRLF +
  '{$RUNONLY}' + CRLF +
  '{$IMPLICITBUILD ON}' + CRLF + CRLF +
  'requires' + CRLF +
  '  vcl50,' + CRLF +
  '  ADK;' + CRLF + CRLF +
  'contains' + CRLF +
  '  Unit1 in ''Unit1.pas'';'  + CRLF + CRLF +
  'end.';
end;

procedure TAddinProjectCreator.NewDefaultModule;
var
   ModuleCreator: TAddinModuleCreator;
begin
   ModuleCreator := TAddinModuleCreator.Create();
   ToolServices.ModuleCreate( ModuleCreator, [ cmAddToProject, cmMainForm, cmMarkModified{, cmShowForm, cmUnNamed} ] );
   ModuleCreator.Free();
end;

procedure TAddinProjectCreator.NewProjectResource(Module: TIModuleInterface);
begin
end;



constructor TAddinModuleCreator.Create;
begin
  inherited Create;
end;

function TAddinModuleCreator.Existing: Boolean;
begin
   result := false;
end;

function TAddinModuleCreator.GetAncestorName: string;
begin
  Result := 'Addin';
end;

function TAddinModuleCreator.GetFileName: string;
begin
  Result := '';
end;

function TAddinModuleCreator.GetFileSystem: string;
begin
  Result := '';
end;

function TAddinModuleCreator.GetFormName: string;
begin
  Result := '';
end;

{$IFNDEF VER100}
function TAddinModuleCreator.GetIntfName: string;
begin
  Result := '';
end;

function TAddinModuleCreator.NewIntfSource(const UnitIdent, Form, Ancestor: string): string;
begin
   result := '';
end;

function TAddinModuleCreator.NewModuleSource(const UnitIdent, Form, Ancestor: string): string;
begin
{$ELSE}
function TAddinModuleCreator.NewModuleSource(UnitIdent, FormIdent, AncestorIdent: string): string;
var
   Form,
   Ancestor : string;
begin
   Form := FormIdent;
   Ancestor := AncestorIdent;
{$ENDIF}

   result := 'unit ' + UnitIdent + ';' + CRLF + CRLF +

             'interface' + CRLF + CRLF +

             'uses' + CRLF +
             '   ADKMng;' + CRLF + CRLF +

             'type' + CRLF +
             '  T' + Form + ' = class(T' + Ancestor + ')' + CRLF +
             '  private' + CRLF +
             '    { Private declarations }' + CRLF +
             '  public' + CRLF +
             '    { Public declarations }' + CRLF +
             '  end;' + CRLF + CRLF + CRLF +

             'implementation' + CRLF + CRLF +

             '{$R *.DFM}' + CRLF + CRLF +

             '// NOTA IMPORTANTE: Se si cambia il nome del datamodule Addin,' + CRLF +
             '// ricordarsi di cambiare il tipo nella procedura sottostante.' + CRLF +
             '// (Delphi cambia la dichiarazione, ma non la procedura stessa.' + CRLF +
             'initialization' + CRLF +
             '  InitAddin(hInstance, T' + Form + ');' + CRLF + CRLF +

             'end.';
end;

procedure TAddinModuleCreator.FormCreated(Form: TIFormInterface);
begin
end;


procedure RegisterContainerModule;
begin
   RegisterCustomModule( TAddin, TCustomModule );
end;

procedure Register;
begin
   RegisterLibraryExpert(TAddinWizard.Create);
end;	   


initialization
   RegisterContainerModule;

finalization

end.

